/*
Copyright (c) 2007 Matt Williams matt@milliams.com

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License or (at
your option) version 3 or, at the discretion of KDE e.V. (which shall
act as a proxy as in section 14 of the GPLv3), any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "kqtisimplechoice.h"

#include "kqtiflowstatic.h"

KQtiSimpleChoice::KQtiSimpleChoice(const QString& identifier, bool fixed) : KQtiChoice(identifier, fixed)
{
}

KQtiSimpleChoice::KQtiSimpleChoice(const QDomElement& element) : KQtiChoice(element)
{
    qDebug("Building simpleChoice");
    for(uint i=0; i<element.childNodes().length(); i++)
    {
        qDebug(" simpleChoice child");
        QDomNode node = element.childNodes().item(i);
        if(node.isElement())
        {
            qDebug("  is Element");
            KQtiFlowStatic* flowStatic = new KQtiFlowStatic(node.toElement());
            addFlowStatic(flowStatic);
        }
        else if(node.isCharacterData())
        {
            qDebug("  is CharacterData");
        }
    }
}

KQtiSimpleChoice::~KQtiSimpleChoice()
{
}

void KQtiSimpleChoice::addFlowStatic(KQtiFlowStatic* flowStatic)
{
    qDebug("Add flowStatic");
    mFlowStatics.append(flowStatic);
}

QDomElement KQtiSimpleChoice::element() const
{
    QDomDocument doc;
    QDomElement simpleChoiceElement = doc.createElement("simpleChoice");
    
    simpleChoiceElement.setAttribute("identifier", identifier());
    simpleChoiceElement.setAttribute("fixed", isFixed());
        
    foreach(KQtiFlowStatic* flowStatic, flowStatics())
    {
        simpleChoiceElement.appendChild(flowStatic->element());
    }
    
    return simpleChoiceElement;
}
