/***************************************************************************
 *   Copyright (C) 2010 by Volker Lanz <vl@fidra.de>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#if !defined(IMPORTMODEL__H)

#define IMPORTMODEL__H

#include "core/types.h"

#include <QAbstractItemModel>
#include <QSet>

class QVariant;

class ImportModel : public QAbstractItemModel
{
	Q_OBJECT

	public:
		enum ImportModelColumns
		{
			importCol = 0,
			dateCol = 1,
			nameCol = 2,
			distanceCol = 3,
			durationCol = 4,
			categoryCol = 5,
			equipmentCol = 6,

			lastImportModelColumn
		};

		static const int sortingRole = Qt::UserRole;

	public:
		ImportModel(QObject* parent, Profile& p, Activities& a);

	public:
		int rowCount(const QModelIndex& = QModelIndex()) const { return m_Activities.size(); }
		int columnCount(const QModelIndex& = QModelIndex()) const { return lastImportModelColumn; }
		QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
		QVariant headerData(int section, Qt::Orientation  orientation, int role = Qt::DisplayRole) const;
		Qt::ItemFlags flags(const QModelIndex& index) const;
		bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
		QModelIndex parent(const QModelIndex&) const { return QModelIndex(); }
		QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;

		void selectAllImports();
		void unselectAllImports();

		void setAllCategories(Category* c);
		void setAllEquipments(Equipment* e);

		const QSet<const Activity*>& importActivities() const { return m_ImportActivities; }
		const Activities& activities() const { return m_Activities; }

	protected:
		void emitAllChanged();

	private:
		Profile& m_Profile;
		Activities& m_Activities;
		QSet<const Activity*> m_ImportActivities;
};



#endif

